import { ArrayIteratee, ArrayNarrowingIteratee, Cast, IfCouldBe, KeyNarrowingIteratee, Narrow, Nil, ObjectIteratee, ValueNarrowingIteratee } from '../interfaces';
declare type DefiniteValueMatches<T, O> = {
    [K in keyof T]: T[K] extends O ? T[K] : never;
}[keyof T];
declare type PossibleValueMatches<T, O> = {
    [K in keyof T]: IfCouldBe<T[K], O, Narrow<T[K], O>>;
}[keyof T];
declare type DefiniteKeyMatches<T, O> = {
    [K in keyof T]: Cast<K, string> extends O ? T[K] : never;
}[keyof T];
declare type PossibleKeyMatches<T, O> = {
    [K in keyof T]: IfCouldBe<Cast<K, string>, O, T[K]>;
}[keyof T];
/**
 * Iterates over elements of `collection`, returning the first element `predicate` returns truthy for.
 *
 * Contribution to minified bundle size, when it is the only function imported:
 * - Lodash: 15,060 bytes
 * - Micro-dash: 262 bytes
 */
export declare function find<I, O>(array: Nil | readonly I[], predicate: ArrayNarrowingIteratee<O>, fromIndex?: number): Extract<I, O> | Extract<O, I> | undefined;
export declare function find<T>(array: Nil | readonly T[], predicate: ArrayIteratee<T, boolean>, fromIndex?: number): T | undefined;
export declare function find<I, T extends NonNullable<I>, O, F extends number | undefined = undefined>(object: I, predicate: ValueNarrowingIteratee<T, O>, fromIndex?: F): (DefiniteValueMatches<T, O> extends never ? undefined : never) | IfCouldBe<F, number, undefined> | IfCouldBe<I, Nil, undefined> | PossibleValueMatches<T, O>;
export declare function find<I, T extends NonNullable<I>, O, F extends number | undefined = undefined>(object: I, predicate: KeyNarrowingIteratee<T, O>, fromIndex?: F): (DefiniteKeyMatches<T, O> extends never ? undefined : never) | IfCouldBe<F, number, undefined> | IfCouldBe<I, Nil, undefined> | PossibleKeyMatches<T, O>;
export declare function find<T>(object: Nil | T, predicate: ObjectIteratee<T, boolean>, fromIndex?: number): T[keyof T] | undefined;
export {};
